// -*- Java -*-
/*!
 * @file  diConsumerImpl.java
 * @brief Data Interpretation Module Consumer
 * @date  $Date$
 *
 * $Id$
 */

import java.io.*;
import java.util.Calendar;
import java.util.Locale;

import jp.go.aist.rtm.RTC.DataFlowComponentBase;
import jp.go.aist.rtm.RTC.Manager;
import jp.go.aist.rtm.RTC.port.CorbaConsumer;
import jp.go.aist.rtm.RTC.port.CorbaPort;
import RTC.ReturnCode_t;

import jp.co.ritecs.DataInterpretationModule.RTC.*;
import jp.co.ritecs.DataInterpretationModule.RTC.diData.*;

/*!
 * @class diConsumerImpl
 * @brief Data Interpretation Module Consumer
 *
 */
public class diConsumerImpl extends DataFlowComponentBase {

  /*!
   * @brief constructor
   * @param manager Maneger Object
   */
	public diConsumerImpl(Manager manager) {  
        super(manager);
        // <rtc-template block="initializer">
        m_diManagementPort = new CorbaPort("diManagement");
        m_diTagPort = new CorbaPort("diTag");
        m_diObjectPort = new CorbaPort("diObject");
        m_diRobotPort = new CorbaPort("diRobot");
        // </rtc-template>

    }

    /**
     *
     * The initialize action (on CREATED->ALIVE transition)
     * formaer rtc_init_entry() 
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onInitialize() {
        // Registration: InPort/OutPort/Service
        // <rtc-template block="registration">
        
        // Set service consumers to Ports
        m_diManagementPort.registerConsumer("if_diManagement", "jp::co::ritecs::DataInterpretationModule::RTC::diManagement", m_if_diManagementBase);
        m_diTagPort.registerConsumer("if_diTag", "jp::co::ritecs::DataInterpretationModule::RTC::diTag", m_if_diTagBase);
        m_diObjectPort.registerConsumer("if_diObject", "jp::co::ritecs::DataInterpretationModule::RTC::diObject", m_if_diObjectBase);
        m_diRobotPort.registerConsumer("if_diRobot", "jp::co::ritecs::DataInterpretationModule::RTC::diRobot", m_if_diRobotBase);
        
        // Set CORBA Service Ports
        addPort(m_diManagementPort);
        addPort(m_diTagPort);
        addPort(m_diObjectPort);
        addPort(m_diRobotPort);
        // </rtc-template>
        System.out.println("Data Interpretation Module Consumer Initialized.");
        return super.onInitialize();
    }

    /***
     *
     * The finalize action (on ALIVE->END transition)
     * formaer rtc_exiting_entry()
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onFinalize() {
        return super.onFinalize();
    }

    /***
     *
     * The startup action when ExecutionContext startup
     * former rtc_starting_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onStartup(int ec_id) {
        return super.onStartup(ec_id);
    }

    /***
     *
     * The shutdown action when ExecutionContext stop
     * former rtc_stopping_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onShutdown(int ec_id) {
        return super.onShutdown(ec_id);
    }

    /***
     *
     * The activated action (Active state entry action)
     * former rtc_active_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onActivated(int ec_id) {
        return super.onActivated(ec_id);
    }

    /***
     *
     * The deactivated action (Active state exit action)
     * former rtc_active_exit()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onDeactivated(int ec_id) {
        return super.onDeactivated(ec_id);
    }

    /***
     *
     * The execution action that is invoked periodically
     * former rtc_active_do()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onExecute(int ec_id) {
        m_if_diManagement = m_if_diManagementBase._ptr();
        m_if_diTag = m_if_diTagBase._ptr();
        m_if_diObject = m_if_diObjectBase._ptr();
        m_if_diRobot = m_if_diRobotBase._ptr();
        
    	System.out.println("");
    	System.out.println("Command list:");
    	System.out.println(" setlogin       : set login information.");
    	System.out.println(" open           : initialize and login tms.");
    	System.out.println(" close          : logout and destroy tms.");
    	System.out.println(" setcontent     : set content object.");
    	System.out.println(" getcontent     : get content object by tagID.");
    	System.out.println(" setcabinet     : set cabinet object.");
    	System.out.println(" getcabinet     : get cabinet object by tagID.");
    	System.out.println(" settag         : set tag object.");
    	System.out.println(" gettagloc      : get tag location by tagID.");
    	System.out.println(" tagbyname      : get tagID by name.");
    	System.out.println(" tagbycomment   : get tagID by comment.");
    	System.out.println(" tagbycabinetid : get tagID by cabinetID.");
    	System.out.println(" setobj         : set object.");
    	System.out.println(" getobj         : get object by objectID.");
    	System.out.println(" objbyname      : get objectID by name.");
    	System.out.println(" objbyplace     : get objectID by place.");
    	System.out.println(" setrobot       : set robot location by robotID.");
    	System.out.println(" getrobot       : get robot location by robotID.");
    	System.out.println(" robotbyname    : get robotID by name");
    	System.out.println(">");

    	String stCmd;
    	stCmd = GetInputConsole();

    	if (stCmd.equals("setlogin") == true) {
    		// set login information.
    		SetLoginInfo();
    	} else if (stCmd.equals("open") == true) {
    		// open
    		Open();
    	} else if (stCmd.equals("close") == true) {
    		// close
    		Close();
    	} else if (stCmd.equals("setcontent") == true) {
    		// set content object
    		SetContentObject();
    	} else if (stCmd.equals("getcontent") == true) {
    		// get content object by tagID
    		GetContentObject();
    	} else if (stCmd.equals("setcabinet") == true) {
    		// set cabinet object
    		SetCabinetObject();
    	} else if (stCmd.equals("getcabinet") == true) {
    		// get cabinet object by tagID
    		GetCabinetObject();
    	} else if (stCmd.equals("settag") == true) {
    		// set tag object
    		SetTagObject();
    	} else if (stCmd.equals("gettagloc") == true) {
    		// get tag location by tagID
    		GetTagLocation();
    	} else if (stCmd.equals("tagbyname") == true) {
    		// get tagID by name
    		GetTagByName();
    	} else if (stCmd.equals("tagbycomment") == true) {
    		// get tagID by comment
    		GetTagByComment();
    	} else if (stCmd.equals("tagbycabinetid") == true) {
    		// get tagID by cabinetid
    		GetTagByCabinetID();
    	} else if (stCmd.equals("setobj") == true) {
    		// set object
    		SetObject();
    	} else if (stCmd.equals("getobj") == true) {
    		// get object by objectID
    		GetObject();
    	} else if (stCmd.equals("objbyname") == true) {
    		// get objectID by name
    		GetObjectByName();
    	} else if (stCmd.equals("objbyplace") == true) {
    		// get objectID by place
    		GetObjectByPlace();
    	} else if (stCmd.equals("setrobot") == true) {
    		// set robot location by robotID
    		SetRobotLocation();
    	} else if (stCmd.equals("getrobot") == true) {
    		// get robot location by robotID
    		GetRobotLocation();
    	} else if (stCmd.equals("robotbyname") == true) {
    		// get robotID by name
    		GetRobotByName();
    	} else {
    		System.out.println("command not found.");
    	}
   	

        return super.onExecute(ec_id);
    }

    /***
     *
     * The aborting action when main logic error occurred.
     * former rtc_aborting_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
  @Override
  public ReturnCode_t onAborting(int ec_id) {
      return super.onAborting(ec_id);
  }

    /***
     *
     * The error action in ERROR state
     * former rtc_error_do()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    public ReturnCode_t onError(int ec_id) {
        return super.onError(ec_id);
    }

    /***
     *
     * The reset action that is invoked resetting
     * This is same but different the former rtc_init_entry()
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onReset(int ec_id) {
        return super.onReset(ec_id);
    }

    /***
     *
     * The state update action that is invoked after onExecute() action
     * no corresponding operation exists in OpenRTm-aist-0.2.0
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onStateUpdate(int ec_id) {
        return super.onStateUpdate(ec_id);
    }

    /***
     *
     * The action that is invoked when execution context's rate is changed
     * no corresponding operation exists in OpenRTm-aist-0.2.0
     *
     * @param ec_id target ExecutionContext Id
     *
     * @return RTC::ReturnCode_t
     * 
     * 
     */
    @Override
    protected ReturnCode_t onRateChanged(int ec_id) {
        return super.onRateChanged(ec_id);
    }
//
    
	// Set Login Info.
	void SetLoginInfo()
	{
		String deviceid;
		String userid;
		String password;
	
		System.out.println("set login information.");
		System.out.println("deviceid > ");
		deviceid = GetInputConsole();
		System.out.println("userid > ");
		userid = GetInputConsole();
		System.out.println("password > ");
		password = GetInputConsole();
	
		long res = m_if_diManagement.setLoginInfo(deviceid, userid, password);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
	}
	
	// Open
	void Open()
	{
		System.out.println("open.");
		long res = m_if_diManagement.Open();
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
	}
	
	// Close
	void Close()
	{
		System.out.println("close.");
		long res = m_if_diManagement.Close();
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
	}
	
	// Set Content Object
	void SetContentObject()
	{
		System.out.println("set content object.");
		
		try {
			String number;
			int num;
			System.out.println("Input the number of contents>");
			number = GetInputConsole();
			num = Integer.parseInt(number);
			
			String x, y, z;
			
			diTagInfo[] taginfos = new diTagInfo[num];
			for(int i=0; i < num; i++) {
				
				taginfos[i] = new diTagInfo();
				System.out.println("Input tagid" + (i+1) + ">");
				taginfos[i].tagid = GetInputConsole();
				
				diContentObjectInfo _obj = new diContentObjectInfo();
				_obj.name = "name";
				_obj.color = 1;
				_obj.size = "size";
				_obj.type = 1;
				_obj.manufacturer = "manufacturer";
				System.out.println("set registration");
	    		diTimeVal date = new diTimeVal();
	    		date.msec = 0;
				_obj.registration = date;
				System.out.println("registration set");
				_obj.comment = "comment";
				_obj.width = 1;
				_obj.depth = 1;
				_obj.height = 1;
				_obj.history = date;
				_obj.status = 1;
				_obj.schedule = "schedule";
				_obj.cabinettype = 1;
				System.out.println("Input cabinetid" + (i+1) + ">");
				_obj.cabinetid = GetInputConsole();
				
				diTagObjectInfo obj = new diTagObjectInfo();
				obj.m_contentObjectInfo(_obj);
				taginfos[i].obj = obj;
				
				diTagLocationInfo loc = new diTagLocationInfo();
				loc.additionalInfo = "additionalInfo";
				loc.time = date;
				System.out.println("Input coordinateX" + (i+1) + ">");
				x = GetInputConsole();
				loc.coordinateX = Double.parseDouble(x);
				System.out.println("Input coordinateY" + (i+1) + ">");
				y = GetInputConsole();
				loc.coordinateY = Double.parseDouble(y);
				System.out.println("Input coordinateZ" + (i+1) + ">");
				z = GetInputConsole();
				loc.coordinateZ = Double.parseDouble(z);
				loc.orientP = 1;
				loc.orientR = 1;
				loc.orientY = 1;
				loc.velocityX = 1;
				loc.velocityY = 1;
				loc.velocityZ = 1;
				loc.locType = 1;
				
				taginfos[i].loc = loc;
				
				diTagTaskInfo task = new diTagTaskInfo();
				task.task = "task";
				
				taginfos[i].task = task;

			}
					
			System.out.println("call setcontentobject");
			long res = m_if_diTag.setContentObject(taginfos);
			if (res == 0) {
				System.out.println("ok.");
			} else {
				System.out.println("error[" + res + "]");
				return;
			}
		}
		catch(NumberFormatException nfe) {
			System.out.println("͂Ă");
		}
		
	}
	
	// Get Content Object
	void GetContentObject()
	{
		System.out.println("get content object.");
		String tagid;
		// Get TagID
		System.out.println("TagID> ");
		tagid = GetInputConsole();
		
		diContentObjectInfoHolder content = new diContentObjectInfoHolder();
		content.value = new diContentObjectInfo();
		long res = m_if_diTag.getContentObjectByTag(tagid, content);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
			return;
		}
		
		diContentObjectInfo info = new diContentObjectInfo();
		info = content.value;
		
		System.out.println("------------------------");
		System.out.println("name: " + info.name);
		System.out.println("color: " + info.color);
		System.out.println("size: " + info.size);
		System.out.println("type: " + info.type);
		System.out.println("manufacturer: " + info.manufacturer);
		System.out.println("registration: " + info.registration.msec);
		System.out.println("comment: " + info.comment);
		System.out.println("width: " + info.width);
		System.out.println("depth: " + info.depth);
		System.out.println("height: " + info.height);
		System.out.println("history: " + info.history.msec);
		System.out.println("status: " + info.status);
		System.out.println("schedule: " + info.schedule);
		System.out.println("cabinettype: " + info.cabinettype);
		System.out.println("cabinetid: " + info.cabinetid);
		
	}
	
	// Set Cabinet Object
	void SetCabinetObject()
	{
		System.out.println("set cabinet object.");
		
		try {
			String number;
			int num;
			System.out.println("Input the number of cabinets>");
			number = GetInputConsole();
			num = Integer.parseInt(number);
			
			String x, y, z;
			
			diTagInfo[] taginfos = new diTagInfo[num];
			for(int i=0; i < num; i++) {
				
				taginfos[i] = new diTagInfo();
				System.out.println("Input tagid" + (i+1) + ">");
				taginfos[i].tagid = GetInputConsole();
				
				diCabinetObjectInfo _obj = new diCabinetObjectInfo();
				_obj.name = "name";
				_obj.color = 1;
				_obj.size = "size";
				_obj.type = 1;
				_obj.manufacturer = "manufacturer";
	    		diTimeVal date = new diTimeVal();
	    		date.msec = 0;
				_obj.registration = date;
				_obj.additionalinfo = "additionalinfo";
				_obj.width = 1;
				_obj.depth = 1;
				_obj.height = 1;
				_obj.capacity = 1;
				_obj.space = 1;
				_obj.sens_start_x = 1;
				_obj.sens_start_y = 1;
				_obj.sens_start_z = 1;
				_obj.sens_width = 1;

				try{
					String contentnum;
					int contents;
					System.out.println("Input number of contents");
					contentnum = GetInputConsole();
					contents = Integer.parseInt(contentnum);
					String[] contentids = new String[contents];
					for(int j=0; j<contents; j++) {
						System.out.println("Input cotent" + (j+1) + ">");
						contentids[j] = GetInputConsole();
					}
					_obj.contentids = contentids;
				}
				catch(NumberFormatException nfe) {
					System.out.println("͂Ă");
					return;
				}
				
				diTagObjectInfo obj = new diTagObjectInfo();
				obj.m_cabinetObjectInfo(_obj);
				taginfos[i].obj = obj;
				
				diTagLocationInfo loc = new diTagLocationInfo();
				loc.additionalInfo = "additionalInfo";
				loc.time = date;
				System.out.println("Input coordinateX" + (i+1) + ">");
				x = GetInputConsole();
				loc.coordinateX = Double.parseDouble(x);
				System.out.println("Input coordinateY" + (i+1) + ">");
				y = GetInputConsole();
				loc.coordinateY = Double.parseDouble(y);
				System.out.println("Input coordinateZ" + (i+1) + ">");
				z = GetInputConsole();
				loc.coordinateZ = Double.parseDouble(z);
				loc.orientP = 1;
				loc.orientR = 1;
				loc.orientY = 1;
				loc.velocityX = 1;
				loc.velocityY = 1;
				loc.velocityZ = 1;
				loc.locType = 1;
				
				taginfos[i].loc = loc;
				
				diTagTaskInfo task = new diTagTaskInfo();
				task.task = "task";
				
				taginfos[i].task = task;

			}
			
			System.out.println("call setcabinetobject");
			long res = m_if_diTag.setCabinetObject(taginfos);
			if (res == 0) {
				System.out.println("ok.");
			} else {
				System.out.println("error[" + res + "]");
				return;
			}
		}
		catch(NumberFormatException nfe) {
			System.out.println("͂Ă");
		}

	}

    
	// Get Cabinet Object
	void GetCabinetObject()
	{
		System.out.println("get cabinet object.");
		String tagid;
		// Get TagID
		System.out.println("TagID> ");
		tagid = GetInputConsole();
		
		diCabinetObjectInfoHolder cabinet = new diCabinetObjectInfoHolder();
		cabinet.value = new diCabinetObjectInfo();
		long res = m_if_diTag.getCabinetObjectByTag(tagid, cabinet);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
			return;
		}
		
		diCabinetObjectInfo info = new diCabinetObjectInfo();
		info = cabinet.value;
		
		System.out.println("------------------------");
		System.out.println("name: " + info.name);
		System.out.println("color: " + info.color);
		System.out.println("size: " + info.size);
		System.out.println("type: " + info.type);
		System.out.println("manufacturer: " + info.manufacturer);
		System.out.println("registration: " + info.registration.msec);
		System.out.println("additionalinfo: " + info.additionalinfo);
		System.out.println("width: " + info.width);
		System.out.println("depth: " + info.depth);
		System.out.println("height: " + info.height);
		System.out.println("capacity: " + info.capacity);
		System.out.println("space: " + info.space);
		System.out.println("sens_start_x: " + info.sens_start_x);
		System.out.println("sens_start_y: " + info.sens_start_y);
		System.out.println("sens_start_z: " + info.sens_start_z);
		System.out.println("sens_width: " + info.sens_width);
		
		long contentnum = info.contentids.length;
		for(int i=0; i<contentnum; i++) {
			System.out.println("contentids: " + info.contentids[i]);
		}
		
	}
	
	// Set Tag Object
	void SetTagObject()
	{
		System.out.println("set tag object.");
		
		try {
			String number;
			int num;
			System.out.println("Input the number of tag objects>");
			number = GetInputConsole();
			num = Integer.parseInt(number);
			
			String x, y, z;
			
			diTagInfo[] taginfos = new diTagInfo[num];
			for(int i=0; i < num; i++) {
				
				taginfos[i] = new diTagInfo();
				System.out.println("Input tagid" + (i+1) + ">");
				taginfos[i].tagid = GetInputConsole();
				
				diTagObjectInfoSuper _obj = new diTagObjectInfoSuper();
				_obj.name = "name";
				_obj.color = 1;
				_obj.size = "size";
				
				diTagObjectInfo obj = new diTagObjectInfo();
				obj.m_tagObjectInfo(_obj);
				taginfos[i].obj = obj;
				
				diTagLocationInfo loc = new diTagLocationInfo();
				loc.additionalInfo = "additionalInfo";
	    		diTimeVal date = new diTimeVal();
	    		date.msec = 0;
				loc.time = date;
				System.out.println("Input coordinateX" + (i+1) + ">");
				x = GetInputConsole();
				loc.coordinateX = Double.parseDouble(x);
				System.out.println("Input coordinateY" + (i+1) + ">");
				y = GetInputConsole();
				loc.coordinateY = Double.parseDouble(y);
				System.out.println("Input coordinateZ" + (i+1) + ">");
				z = GetInputConsole();
				loc.coordinateZ = Double.parseDouble(z);
				loc.orientP = 1;
				loc.orientR = 1;
				loc.orientY = 1;
				loc.velocityX = 1;
				loc.velocityY = 1;
				loc.velocityZ = 1;
				loc.locType = 1;
				
				taginfos[i].loc = loc;
				
				diTagTaskInfo task = new diTagTaskInfo();
				task.task = "task";
				
				taginfos[i].task = task;

			}
					
			System.out.println("call settagobject");
			long res = m_if_diTag.setTagObject(taginfos);
			if (res == 0) {
				System.out.println("ok.");
			} else {
				System.out.println("error[" + res + "]");
				return;
			}
		}
		catch(NumberFormatException nfe) {
			System.out.println("͂Ă");
		}
	}

	
	// Get Tag Location
	void GetTagLocation()
	{
		System.out.println("get tag location.");
		String tagid;
		// Get TagID
		System.out.println("TagID> ");
		tagid = GetInputConsole();
		
		diTagLocationInfoHolder loc = new diTagLocationInfoHolder();
		loc.value = new diTagLocationInfo();
		long res = m_if_diTag.getTagLocationByTag(tagid, loc);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
			return;
		}
		
		diTagLocationInfo info = new diTagLocationInfo();
		info = loc.value;
		
		System.out.println("------------------------");
		System.out.println("additionalInfo: " + info.additionalInfo);
		System.out.println("time: " + info.time.msec);
		System.out.println("coordinateX: " + info.coordinateX);
		System.out.println("coordinateY: " + info.coordinateY);
		System.out.println("coordinateZ: " + info.coordinateZ);
		System.out.println("orientP: " + info.orientP);
		System.out.println("orientR: " + info.orientR);
		System.out.println("orientY: " + info.orientY);
		System.out.println("velocityX: " + info.velocityX);
		System.out.println("velocityY: " + info.velocityY);
		System.out.println("velocityZ: " + info.velocityZ);
		System.out.println("locType: " + info.locType);

	}
	
	// Get Tag By Name
	void GetTagByName()
	{
		System.out.println("get tag by name.");
		
		String name;
		System.out.println("Name>");
		name = GetInputConsole();
		
		diStringListHolder tagids = new diStringListHolder();
		long res = m_if_diTag.getTagByName(name, tagids);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		
		String[] tagIDs = new String[tagids.value.length];
		tagIDs = tagids.value;

		System.out.print("tagids:");
		for(int i=0; i<tagIDs.length; i++) {
			System.out.print(" " + tagIDs[i]);
		}
		System.out.println("");
	}
	
	//Get Tag By Comment
	void GetTagByComment()
	{
		System.out.println("get tag by comment.");
		
		String comment;
		System.out.println("Comment>");
		comment = GetInputConsole();
		
		diStringListHolder tagids = new diStringListHolder();
		long res = m_if_diTag.getTagByComment(comment, tagids);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		
		String[] tagIDs = new String[tagids.value.length];
		tagIDs = tagids.value;

		System.out.print("tagids:");
		for(int i=0; i<tagIDs.length; i++) {
			System.out.print(" " + tagIDs[i]);
		}
		System.out.println("");
	}
	
	// Get Tag By CabinetID
	void GetTagByCabinetID()
	{
		System.out.println("get tag by cabinetid.");
		
		String cabinetid;
		System.out.println("CabinetID>");
		cabinetid = GetInputConsole();
		
		diStringListHolder tagids = new diStringListHolder();
		long res = m_if_diTag.getTagByCabinetID(cabinetid, tagids);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		
		String[] tagIDs = new String[tagids.value.length];
		tagIDs = tagids.value;

		System.out.print("tagids:");
		for(int i=0; i<tagIDs.length; i++) {
			System.out.print(" " + tagIDs[i]);
		}
		System.out.println("");
	}

	// Set Object
	void SetObject()
	{
		System.out.println("set object.");
		
		try {
			String number;
			int num;
			System.out.println("Input the number of objects>");
			number = GetInputConsole();
			num = Integer.parseInt(number);
			
			String x, y, z;
			
			diVID_VisionInfo[] vidinfos = new diVID_VisionInfo[num];
			for(int i=0; i < num; i++) {
				
				vidinfos[i] = new diVID_VisionInfo();
				System.out.println("Input visionid" + (i+1) + ">");
				vidinfos[i].vid = GetInputConsole();
				
				diVisionInfo info = new diVisionInfo();
				info.additionalInfo = "additionalInfo";
	    		diTimeVal date = new diTimeVal();
	    		date.msec = 0;
				info.time = date;
				System.out.println("Input coordinateX" + (i+1) + ">");
				x = GetInputConsole();
				info.coordinateX = Double.parseDouble(x);
				System.out.println("Input coordinateY" + (i+1) + ">");
				y = GetInputConsole();
				info.coordinateY = Double.parseDouble(y);
				System.out.println("Input coordinateZ" + (i+1) + ">");
				z = GetInputConsole();
				info.coordinateZ = Double.parseDouble(z);
				info.orientP = 0;
				info.orientR = 0;
				info.orientY = 0;
				info.velocityX = 0;
				info.velocityY = 0;
				info.velocityZ = 0;
				info.action = "action";
				byte[] a = {0};
				info.image = a;
				info.name = "name";
				info.place = "place";
				info.property = 0;
				info.status = 0;
				
				vidinfos[i].info = info;

			}
					
			System.out.println("call setobject");
			long res = m_if_diObject.setObject(vidinfos);
			if (res == 0) {
				System.out.println("ok.");
			} else {
				System.out.println("error[" + res + "]");
				return;
			}
		}
		catch(NumberFormatException nfe) {
			System.out.println("͂Ă");
		}
	}

	
	// Get Object
	void GetObject()
	{
		System.out.println("get object.");
		String objectid;
		// Get ObjectID
		System.out.println("ObjectID>");
		objectid = GetInputConsole();
		
		diVisionInfoHolder vision = new diVisionInfoHolder();
		vision.value = new diVisionInfo();
		long res = m_if_diObject.getObject(objectid, vision);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		
		diVisionInfo info = new diVisionInfo();
		info = vision.value;
		
		System.out.println("------------------------");
		System.out.println("additionalInfo: " + info.additionalInfo);
		System.out.println("time: " + info.time.msec);
		System.out.println("coordinateX: " + info.coordinateX);
		System.out.println("coordinateY: " + info.coordinateY);
		System.out.println("coordinateZ: " + info.coordinateZ);
		System.out.println("orientP: " + info.orientP);
		System.out.println("orientR: " + info.orientR);
		System.out.println("orientY: " + info.orientY);
		System.out.println("velocityX: " + info.velocityX);
		System.out.println("velocityY: " + info.velocityY);
		System.out.println("velocityZ: " + info.velocityZ);
		System.out.println("action: " + info.action);
		System.out.println("name: " + info.name);
		System.out.println("place: " + info.place);
		System.out.println("property: " + info.property);
		System.out.println("status: " + info.status);
	}
	
	// Get Object By Name
	void GetObjectByName()
	{
		System.out.println("get object by name.");
		
		String name;
		System.out.println("name>");
		name = GetInputConsole();
		
		diStringListHolder objectids = new diStringListHolder();
		long res = m_if_diObject.getObjectByName(name, objectids);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		
		String[] objectIDs = new String[objectids.value.length];
		objectIDs = objectids.value;

		System.out.print("objectids:");
		for(int i=0; i<objectIDs.length; i++) {
			System.out.print(" " + objectIDs[i]);
		}
		System.out.println("");
	}
	
	// Get Object By Place
	void GetObjectByPlace()
	{
		System.out.println("get object by place.");
		
		String place;
		System.out.println("place>");
		place = GetInputConsole();
		
		diStringListHolder objectids = new diStringListHolder();
		long res = m_if_diObject.getObjectByPlace(place, objectids);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		
		String[] objectIDs = new String[objectids.value.length];
		objectIDs = objectids.value;

		System.out.print("objectids:");
		for(int i=0; i<objectIDs.length; i++) {
			System.out.print(" " + objectIDs[i]);
		}
		System.out.println("");
	}
	
	// Set Robot Location By RobotID
	void SetRobotLocation()
	{
		System.out.println("set robot location.");
	}

	// Get Robot Location
	void GetRobotLocation()
	{
		System.out.println("get robot location.");
		/*
		String robotid = "";
		diLocationInfoHolder loc = new diLocationInfoHolder();
		loc.value = new diLocationInfo();
		long res = m_if_diRobot.getRobotLocation(robotid, loc);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		*/
	}
	
	// Get Robot By Name
	void GetRobotByName()
	{
		System.out.println("get robot by name.");
		/*
		String name = "";
		diStringBufferHolder robotids = new diStringBufferHolder();
		long res = m_if_diRobot.getRobotByName(name, robotids);
		if (res == 0) {
			System.out.println("ok.");
		} else {
			System.out.println("error[" + res + "]");
		}
		*/
	}
	
	// 񂩂J_[ɕϊ
	boolean String2Calendar(String stDateTime, Calendar cal)
	{
		String stFind = "";
		String stTemp;
		int start, end;
		int i;
		int[] d = new int[6];

		start = 0;
		for (i = 0; i < 5; i++) {
			if (i < 2) {
				stFind = "/";
			} else if (i == 2) {
				stFind = " ";
			} else {
				stFind = ":";
			}
			end = stDateTime.indexOf(stFind, start);
			if (end == -1) {
				return false;
			}
			if (end >= stDateTime.length()) {
				return false;
			}
			stTemp = stDateTime.substring(start, end);
			start = end + 1;
			if (start >= stDateTime.length()) {
				return false;
			}
			d[i] = Integer.parseInt(stTemp);
		}
		stTemp = stDateTime.substring(start, stDateTime.length());
		d[5] = Integer.parseInt(stTemp);
		if (d[0] <= 1970) {
			return false;
		}
		if (d[1] < 1 || d[1] > 12) {
			return false;
		}
		if (d[2] < 1 || d[2] > 31) {
			return false;
		}
		if (d[3] < 0 || d[3] > 23) {
			return false;
		}
		if (d[4] < 0 || d[4] > 59) {
			return false;
		}
		if (d[5] < 0 || d[5] > 59) {
			return false;
		}
		cal.set(d[0], d[1] - 1, d[2], d[3], d[4], d[5]);
		return true;
	 }
    
	// R\[͏
	public String GetInputConsole()
	{
		InputStreamReader isr = new InputStreamReader(System.in);
		BufferedReader br = new BufferedReader(isr);
		String buf;
		try {
			buf = br.readLine();
		} catch (Exception e) {
			System.out.println(e.getMessage());
			return "";
		}
		return buf;
	}
	 
    // DataInPort declaration
    // <rtc-template block="inport_declare">
    
    // </rtc-template>

    // DataOutPort declaration
    // <rtc-template block="outport_declare">
    
    // </rtc-template>

    // CORBA Port declaration
    // <rtc-template block="corbaport_declare">
    /*!
     */
    protected CorbaPort m_diManagementPort;
    /*!
     */
    protected CorbaPort m_diTagPort;
    /*!
     */
    protected CorbaPort m_diObjectPort;
    /*!
     */
    protected CorbaPort m_diRobotPort;
    
    // </rtc-template>

    // Service declaration
    // <rtc-template block="service_declare">
    
    // </rtc-template>

    // Consumer declaration
    // <rtc-template block="consumer_declare">
    protected CorbaConsumer<diManagement> m_if_diManagementBase = new CorbaConsumer<diManagement>(diManagement.class);
    /*!
     */
    protected diManagement m_if_diManagement;
    protected CorbaConsumer<diTag> m_if_diTagBase = new CorbaConsumer<diTag>(diTag.class);
    /*!
     */
    protected diTag m_if_diTag;
    protected CorbaConsumer<diObject> m_if_diObjectBase = new CorbaConsumer<diObject>(diObject.class);
    /*!
     */
    protected diObject m_if_diObject;
    protected CorbaConsumer<diRobot> m_if_diRobotBase = new CorbaConsumer<diRobot>(diRobot.class);
    /*!
     */
    protected diRobot m_if_diRobot;
    
    // </rtc-template>


}
