// -*-Java-*-

/*!
 * @file  diObjectSVC_impl.java
 * @brief Service implementation code of DataInterpretationModule.idl
 *
 */

import jp.co.ritecs.DataInterpretationModule.RTC.*;
import jp.co.ritecs.DataInterpretationModule.RTC.diData.*;
import jp.go.aist.rtm.RTC.port.CorbaConsumer;

import com.nec.qnes.tms2.RTC.api.*;
import com.nec.qnes.tms2.RTC.data.*;

/*!
 * @class diObjectSVC_impl
 * Example class implementing IDL interface jp::co::ritecs::DataInterpretationModule::RTC::diObject
 */
public class diObjectSVC_impl extends diObjectPOA{

	public CorbaConsumer<Location> m_locationBase;
	protected Location m_location;
	
	public AuthToken m_localtoken;
	
    public diObjectSVC_impl() {
        // Please add extra constructor code here.
    }

    /*
     * Methods corresponding to IDL attributes and operations
     */
    public int setObject(diVID_VisionInfo[] infos) {
        // Please insert your code here and remove the following warning pragma
        // TODO "Code missing in function <int setObject(diData::diVID_VisionInfoList infos)>"
    	System.out.println("Set Object was called.");
    	
    	m_location = m_locationBase._ptr();
    	
    	if(m_localtoken == null) {
    		System.out.println("no login");
    		return -1;
    	}
    	
    	int ret = 0;
    	
    	Location location = m_location.getInstance(m_localtoken);
    	
    	if(location == null) {
    		System.out.println("failed");
    		return -1;
    	}
    	
        VID_VisionInfo[] vidinfos = new VID_VisionInfo[infos.length];
        
    	for(int i=0; i < infos.length; i++) {
    		
    		vidinfos[i] = new VID_VisionInfo();
    		vidinfos[i].vid = infos[i].vid;
    		
    		VisionInfo vision = new VisionInfo();
    		vision.additionalInfo = infos[i].info.additionalInfo;
    		TimeVal date = new TimeVal();
    		date.msec = infos[i].info.time.msec;
    		vision.time = date;
    		vision.coordinateX = infos[i].info.coordinateX;
    		vision.coordinateY = infos[i].info.coordinateY;
    		vision.coordinateZ = infos[i].info.coordinateZ;
    		vision.orientP = infos[i].info.orientP;
    		vision.orientR = infos[i].info.orientR;
    		vision.orientY = infos[i].info.orientY;
    		vision.velocityX = infos[i].info.velocityX;
    		vision.velocityY = infos[i].info.velocityY;
    		vision.velocityZ = infos[i].info.velocityZ;
    		vision.action = infos[i].info.action;
    		vision.image = infos[i].info.image;
    		vision.name = infos[i].info.name;
    		vision.place = infos[i].info.place;
    		vision.property = infos[i].info.property;
    		vision.status = infos[i].info.status;
    		
    		vidinfos[i].info = vision;

    	}
    	
    	System.out.println("Call setVisionInfoByVisionID()");
    	ret = m_location.setVisionInfoByVisionID(vidinfos);
    	
    	System.out.println("return code: " + ret);
    	
    	if(ret < 0) {
    		System.out.println("error");
    	} else {
    		System.out.println("ok");
    	}
    	
        return ret;
        
    }

    public int getObject(String objectID, diVisionInfoHolder info) {
        // Please insert your code here and remove the following warning pragma
        // TODO "Code missing in function <int getObject(String objectID, diData::diVisionInfo info)>"
    	System.out.println("Get Object was called.");
    	
    	m_location = m_locationBase._ptr();
    	
    	if(m_localtoken == null) {
    		System.out.println("no login");
    		return -1;
    	}
    	
    	int ret = 0;
    	
    	Location location = m_location.getInstance(m_localtoken);
    	
    	if(location == null) {
    		System.out.println("failed");
    		return -1;
    	}
    	
    	String visionid = objectID;
    	VisionInfoHolder vision = new VisionInfoHolder();
    	
    	System.out.println("CALL getVisionInfoByVisionID");
    	
    	ret = m_location.getVisionInfoByVisionID(objectID, vision);
    	
    	System.out.println("return code: " + ret);
    	
    	if(ret < 0) {
    		System.out.println("error");
    		
    		info.value = new diVisionInfo();
    		info.value.additionalInfo = "";
    		diTimeVal date = new diTimeVal();
    		date.msec = 0;
    		info.value.time = date;
    		info.value.coordinateX = 0;
    		info.value.coordinateY = 0;
    		info.value.coordinateZ = 0;
    		info.value.orientP = 0;
    		info.value.orientR = 0;
    		info.value.orientY = 0;
    		info.value.velocityX = 0;
    		info.value.velocityY = 0;
    		info.value.velocityZ = 0;
    		
    		info.value.action = "";
			byte[] a = {0};
    		info.value.image = a;
    		info.value.name = "";
    		info.value.place = "";
    		info.value.property = 0;
    		info.value.status = 0;
    	} else {
    		VisionInfo visioninfo = vision.value;
    		
    		info.value = new diVisionInfo();
    		info.value.additionalInfo = visioninfo.additionalInfo;
    		diTimeVal date = new diTimeVal();
    		date.msec = visioninfo.time.msec;
    		info.value.time = date;
    		info.value.coordinateX = visioninfo.coordinateX;
    		info.value.coordinateY = visioninfo.coordinateY;
    		info.value.coordinateZ = visioninfo.coordinateZ;
    		info.value.orientP = visioninfo.orientP;
    		info.value.orientR = visioninfo.orientR;
    		info.value.orientY = visioninfo.orientY;
    		info.value.velocityX = visioninfo.velocityX;
    		info.value.velocityY = visioninfo.velocityY;
    		info.value.velocityZ = visioninfo.velocityZ;
    		
    		info.value.action = visioninfo.action;
    		info.value.image = visioninfo.image;
    		info.value.name = visioninfo.name;
    		info.value.place = visioninfo.place;
    		info.value.property = visioninfo.property;
    		info.value.status = visioninfo.status;
    		
    		System.out.println("ok");
    	}
    	
        return ret;
    }

    public int getObjectByName(String name, diStringListHolder objectIDs) {
        // Please insert your code here and remove the following warning pragma
        // TODO "Code missing in function <int getObjectByName(String name, diData::diStringList objectIDs)>"
        System.out.println("Get Object By Name was called.");
        
        m_location = m_locationBase._ptr();
         
         if(m_localtoken == null) {
         	System.out.println("no login");
         	return -1;
         }
         
         int ret = 0;
         
         Location location = m_location.getInstance(m_localtoken);
         
         if(location == null) {
         	System.out.println("failed");
         	return -1;
         }
         
         VisionInfo info = new VisionInfo();
         
         String[] keys = new String[]{"NAME"};
         info.name = name;
         info.additionalInfo = "additionalInfo";
         TimeVal date = new TimeVal();
         date.msec = 0;
         info.time = date;
         info.coordinateX = 0;
         info.coordinateY = 0;
         info.coordinateZ = 0;
         info.orientP = 0;
         info.orientR = 0;
         info.orientY = 0;
         info.velocityX = 0;
         info.velocityY = 0;
         info.velocityZ = 0;
         info.action = "action";
         byte[] a = {0};
         info.image = a;
         info.place = "place";
         info.property = 0;
         info.status = 0;         
         
         VisionInfo_Key info_key = new VisionInfo_Key(info, keys);
         VisionInfo_Key[] infos_keys = new VisionInfo_Key[]{info_key};
         
         StringListListHolder visionIds = new StringListListHolder();

         System.out.println("CALL getVisionIDByVisionInfo()");
         ret = m_location.getVisionIDByVisionInfo(infos_keys, visionIds);
         
         System.out.println("return code: " + ret);
         
         if(ret < 0) {
         	System.out.println("error");
         	objectIDs.value = new String[1];
         	objectIDs.value[0] = "";
         } else {
        	 int objectnum = 0;
          	for(int i=0; i<visionIds.value.length; i++) {
         		String[] visionIdsForEachInfo = visionIds.value[i];
         		for(int j=0; j<visionIdsForEachInfo.length; j++) {
         			objectnum++;
         		}
         	}
          	objectIDs.value = new String[objectnum];
          	int k = 0;
        	 for(int i=0; i<visionIds.value.length; i++) {
        		 String[] visionIdsForEachInfo = visionIds.value[i];
        		 for(int j=0; j<visionIdsForEachInfo.length; j++) {
        			 objectIDs.value[k] = new String();
        			 objectIDs.value[k] = visionIdsForEachInfo[j];
        			 k++;
        			 }
        		 }
        	 System.out.println("ok");
         }
         return ret;
    }

    public int getObjectByPlace(String place, diStringListHolder objectIDs) {
        // Please insert your code here and remove the following warning pragma
        // TODO "Code missing in function <int getObjectByPlace(String place, diData::diStringList objectIDs)>"
        System.out.println("Get Object By Place was called.");
        
        m_location = m_locationBase._ptr();
         
         if(m_localtoken == null) {
         	System.out.println("no login");
         	return -1;
         }
         
         int ret = 0;
         
         Location location = m_location.getInstance(m_localtoken);
         
         if(location == null) {
         	System.out.println("failed");
         	return -1;
         }
         
         VisionInfo info = new VisionInfo();
         
         String[] keys = new String[]{"PLACE"};
         info.place = place;
         info.name = "name";
         info.additionalInfo = "additionalInfo";
         TimeVal date = new TimeVal();
         date.msec = 0;
         info.time = date;
         info.coordinateX = 0;
         info.coordinateY = 0;
         info.coordinateZ = 0;
         info.orientP = 0;
         info.orientR = 0;
         info.orientY = 0;
         info.velocityX = 0;
         info.velocityY = 0;
         info.velocityZ = 0;
         info.action = "action";
         byte[] a = {0};
         info.image = a;
         info.property = 0;
         info.status = 0;         
         
         VisionInfo_Key info_key = new VisionInfo_Key(info, keys);
         VisionInfo_Key[] infos_keys = new VisionInfo_Key[]{info_key};
         
         StringListListHolder visionIds = new StringListListHolder();

         System.out.println("CALL getVisionIDByVisionInfo()");
         ret = m_location.getVisionIDByVisionInfo(infos_keys, visionIds);
         
         System.out.println("return code: " + ret);
                  
         if(ret < 0) {
         	System.out.println("error");
         	objectIDs.value = new String[1];
         	objectIDs.value[0] = "";
         } else {
        	 int objectnum = 0;
          	for(int i=0; i<visionIds.value.length; i++) {
         		String[] visionIdsForEachInfo = visionIds.value[i];
         		for(int j=0; j<visionIdsForEachInfo.length; j++) {
         			objectnum++;
         		}
         	}
          	objectIDs.value = new String[objectnum];
          	int k = 0;
        	 for(int i=0; i<visionIds.value.length; i++) {
        		 String[] visionIdsForEachInfo = visionIds.value[i];
        		 for(int j=0; j<visionIdsForEachInfo.length; j++) {
        			 objectIDs.value[k] = new String();
        			 objectIDs.value[k] = visionIdsForEachInfo[j];
        			 k++;
        			 }
        		 }
        	 System.out.println("ok");
         }
         return ret;
    }

//  End of example implementational code
}
